# NSEPython

NSEPython is a Python library for dealing with [NSEIndia](nseindia.com) APIs.

## Installation

Use the package manager [pip](https://pypi.org/project/nsepython/) to install nsepython.

```bash
pip install nsepython
```
## Documentation

- Fetch All Indices.
- Fetch List of All FNO Stocks.
- Fetch Option Chain Data.
- An Advanced OI Chain Visualizer Function.
- Getting ATM Strikes.
- Stocks and Derivatives API Fetch Live Stock and Derivatives Prices and all detailed data.
- Holiday API
- Event Calendar API
- Results API
- Past Results API

For Full Documentation and Sample Code, Refer - https://forum.unofficed.com/t/nsepython-documentation/376

## Contributing
For Discussion and Improving this Code, Join - https://www.unofficed.com/chat/

## License
[MIT](https://choosealicense.com/licenses/mit/)
